==> yy-formulas-1.0.14.tgz: package/es/components/ReferComponents.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (typeof call === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import { polyfill } from 'react-lifecycles-compat';
import jQuery from 'jquery';
import Select, { Option } from 'rc-select'; // import Select from 'react-select'

var ReferComponents =
/*#__PURE__*/
function (_React$Component) {
  _inherits(ReferComponents, _React$Component);

  function ReferComponents(props) {
    var _this;

    _classCallCheck(this, ReferComponents);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ReferComponents).call(this, props));
    _this.onFocus = _this.onFocus.bind(_assertThisInitialized(_this));
    _this.onSearch = _this.onSearch.bind(_assertThisInitialized(_this));
    _this.onSelect = _this.onSelect.bind(_assertThisInitialized(_this));
    _this.onChange = _this.onChange.bind(_assertThisInitialized(_this));
    _this.state = {
      options: [],
      searchValue: '',
      value: _this.props.value && _this.props.value.title ? _this.props.value && _this.props.value.title : ''
    };
    return _this;
  }

  _createClass(ReferComponents, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      if (this.props.defaultCode) {
        this.selecteRef.focus();
      }
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      if (JSON.stringify(nextProps.value) != JSON.stringify(this.state.value)) {
        this.setState({
          value: nextProps.value.title
        });
      }
    }
  }, {
    key: "onSearch",
    value: function onSearch(searchValue) {
      this.setState({
        searchValue: searchValue
      });
    }
  }, {
    key: "onFocus",
    value: function onFocus() {
      var that = this;
      jQuery.ajax({
        url: that.props.url,
        data: JSON.stringify(_extends(that.props.sendData, that.props.fixedData)),
        method: 'POST',
        beforeSend: function beforeSend(xhr, settings) {
          // console.log([xhr,settings])
          that.props.beforeSend(xhr, settings);
          return true;
        },
        contentType: that.props.contentType,
        dataType: that.props.dataType,
        cache: false,
        crossDomain: true,
        success: function success(data) {
          if (data.success) {
            that.setState({
              options: data.data.map(function (item) {
                return _extends(item, {
                  value: item.code,
                  label: item.name
                });
              })
            }, function () {
              if (that.props.defaultCode && that.state.options.length > 0) {
                that.state.options.forEach(function (item) {
                  if (item.code === that.props.defaultCode) {
                    var id = item.id,
                        code = item.code,
                        name = item.name;
                    that.setState({
                      value: name
                    });
                    that.props.onChange({
                      id: id,
                      value: name,
                      code: code,
                      key: id,
                      title: name
                    });
                  }
                });
              }
            });
          } // console.log(data)

        },
        error: function error(err) {
          console.error(err);
        }
      });
    }
  }, {
    key: "onSelect",
    value: function onSelect() {
      var _this2 = this;

      for (var _len = arguments.length, arr = new Array(_len), _key = 0; _key < _len; _key++) {
        arr[_key] = arguments[_key];
      }

      var key = arr[1].key;
      var _arr$1$props = arr[1].props,
          id = _arr$1$props.id,
          value = _arr$1$props.value,
          code = _arr$1$props.code,
          title = _arr$1$props.title;
      this.state.options.forEach(function (item) {
        if (item.id === id) {
          code = item.code;
          title = item.name;
          value = item.name;
        }
      }); // console.log([{key, id, value, code }])
      // this.setState({
      //   value: arr[0]
      // })

      this.setState({
        value: value
      }, function () {
        _this2.props.onChange({
          id: id,
          value: value,
          code: code,
          key: key,
          title: title
        });
      }); // console.log(['select',...arr])
    }
  }, {
    key: "onChange",
    value: function onChange(value) {
      if (value) {
        this.setState({
          value: value
        });
      } else {
        this.props.onChange({});
      } // console.log(arr)

    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      // return (
      //   <Select
      //     options={this.state.options}
      //     onFocus={this.onFocus}
      //     styles={{option:(styles)=>{return Object.assign(styles,{zIndex:9999})}}}
      //   />
      // )
      var _this$props = this.props,
          disabled = _this$props.disabled,
          isCode = _this$props.isCode; // let options = JSON.parse(JSON.stringify(this.state.options))
      // let optionsList = []
      // if(this.state.searchValue && this.state.searchValue.length > 0){
      //   options.forEach((item)=>{
      //     let regexp = new RegExp(this.state.searchValue,'img')
      //     if(regexp.test(item.name)){
      //       optionsList.push(item)
      //     }
      //   })
      // }else{
      //   optionsList = options
      // }
      // console.log(this.state.searchValue,optionsList.length)
      // console.log(this.state.value && this.state.value.value)

      return React.createElement(Select, {
        ref: function ref(_ref) {
          return _this3.selecteRef = _ref;
        },
        showSearch: true,
        allowClear: true,
        combobox: true // backfill
        // disabled
        // multiple
        // filterOption
        ,
        disabled: disabled,
        onFocus: this.onFocus // onSearch={this.onSearch}
        ,
        placeholder: this.props.placeholder,
        notFoundContent: this.props.notFoundContent // notFoundContent="暂无数据"
        ,
        onChange: this.onChange,
        onSelect: this.onSelect,
        value: this.state.value
      }, this.state.options.map(function (item) {
        return React.createElement(Option, {
          value: item.code + ' ' + item.name,
          title: item.name,
          id: item.id // ode={item.code}
          ,
          key: item.id,
          disabled: item.disabled
        }, isCode ? item.code + ' ' + item.name : item.name);
      }));
    }
  }]);

  return ReferComponents;
}(React.Component);

var noop = function noop() {
  return null;
};

ReferComponents.propTypes = {
  url: PropTypes.string,
  method: PropTypes.string,
  contentType: PropTypes.string,
  dataType: PropTypes.string,
  sendData: PropTypes.object,
  fixedData: PropTypes.object,
  beforeSend: PropTypes.func,
  onChange: PropTypes.func,
  disabled: PropTypes.bool,
  value: PropTypes.object,
  isCode: PropTypes.bool,
  placeholder: PropTypes.string,
  notFoundContent: PropTypes.string,
  defaultCode: PropTypes.bool
};
ReferComponents.defaultProps = {
  url: '',
  method: 'POST',
  contentType: 'application/json; charset=utf-8',
  dataType: 'json',
  sendData: {
    refCode: '',
    refType: 'list',
    funcode: '',
    displayFields: ['id', 'code', 'name']
  },
  fixedData: {},
  beforeSend: noop,
  onChange: noop,
  disabled: false,
  value: {},
  isCode: false,
  placeholder: '请输入...',
  notFoundContent: '暂无数据',
  defaultCode: ''
};
polyfill(ReferComponents);
export default ReferComponents;

==> yy-formulas-1.0.15.tgz: package/es/components/ReferComponents.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (typeof call === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import { polyfill } from 'react-lifecycles-compat';
import jQuery from 'jquery';
import Select, { Option } from 'rc-select'; // import Select from 'react-select'

var ReferComponents =
/*#__PURE__*/
function (_React$Component) {
  _inherits(ReferComponents, _React$Component);

  function ReferComponents(props) {
    var _this;

    _classCallCheck(this, ReferComponents);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ReferComponents).call(this, props));
    _this.onFocus = _this.onFocus.bind(_assertThisInitialized(_this));
    _this.onSearch = _this.onSearch.bind(_assertThisInitialized(_this));
    _this.onSelect = _this.onSelect.bind(_assertThisInitialized(_this));
    _this.onChange = _this.onChange.bind(_assertThisInitialized(_this));
    _this.state = {
      options: [],
      searchValue: '',
      value: _this.props.value && _this.props.value.title ? _this.props.value && _this.props.value.title : ''
    };
    return _this;
  }

  _createClass(ReferComponents, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      if (this.props.defaultCode) {
        this.selecteRef.focus();
      }
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      if (JSON.stringify(nextProps.value) != JSON.stringify(this.state.value)) {
        this.setState({
          value: nextProps.value.title
        });
      }
    }
  }, {
    key: "onSearch",
    value: function onSearch(searchValue) {
      this.setState({
        searchValue: searchValue
      });
    }
  }, {
    key: "onFocus",
    value: function onFocus() {
      var that = this;
      jQuery.ajax({
        url: that.props.url,
        data: JSON.stringify(_extends(JSON.parse(JSON.stringify(that.props.sendData)), that.props.fixedData)),
        method: 'POST',
        beforeSend: function beforeSend(xhr, settings) {
          // console.log([xhr,settings])
          that.props.beforeSend(xhr, settings);
          return true;
        },
        contentType: that.props.contentType,
        dataType: that.props.dataType,
        cache: false,
        crossDomain: true,
        success: function success(data) {
          if (data.success) {
            that.setState({
              options: data.data.map(function (item) {
                return _extends(item, {
                  value: item.code,
                  label: item.name
                });
              })
            }, function () {
              if (that.props.defaultCode && that.state.options.length > 0) {
                that.state.options.forEach(function (item) {
                  if (item.code === that.props.defaultCode) {
                    var id = item.id,
                        code = item.code,
                        name = item.name;
                    that.setState({
                      value: name
                    });
                    that.props.onChange({
                      id: id,
                      value: name,
                      code: code,
                      key: id,
                      title: name
                    });
                  }
                });
              }
            });
          } // console.log(data)

        },
        error: function error(err) {
          console.error(err);
        }
      });
    }
  }, {
    key: "onSelect",
    value: function onSelect() {
      var _this2 = this;

      for (var _len = arguments.length, arr = new Array(_len), _key = 0; _key < _len; _key++) {
        arr[_key] = arguments[_key];
      }

      var key = arr[1].key;
      var _arr$1$props = arr[1].props,
          id = _arr$1$props.id,
          value = _arr$1$props.value,
          code = _arr$1$props.code,
          title = _arr$1$props.title;
      this.state.options.forEach(function (item) {
        if (item.id === id) {
          code = item.code;
          title = item.name;
          value = item.name;
        }
      }); // console.log([{key, id, value, code }])
      // this.setState({
      //   value: arr[0]
      // })

      this.setState({
        value: value
      }, function () {
        _this2.props.onChange({
          id: id,
          value: value,
          code: code,
          key: key,
          title: title
        });
      }); // console.log(['select',...arr])
    }
  }, {
    key: "onChange",
    value: function onChange(value) {
      if (value) {
        this.setState({
          value: value
        });
      } else {
        this.props.onChange({});
      } // console.log(arr)

    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      // return (
      //   <Select
      //     options={this.state.options}
      //     onFocus={this.onFocus}
      //     styles={{option:(styles)=>{return Object.assign(styles,{zIndex:9999})}}}
      //   />
      // )
      var _this$props = this.props,
          disabled = _this$props.disabled,
          isCode = _this$props.isCode; // let options = JSON.parse(JSON.stringify(this.state.options))
      // let optionsList = []
      // if(this.state.searchValue && this.state.searchValue.length > 0){
      //   options.forEach((item)=>{
      //     let regexp = new RegExp(this.state.searchValue,'img')
      //     if(regexp.test(item.name)){
      //       optionsList.push(item)
      //     }
      //   })
      // }else{
      //   optionsList = options
      // }
      // console.log(this.state.searchValue,optionsList.length)
      // console.log(this.state.value && this.state.value.value)

      return React.createElement(Select, {
        ref: function ref(_ref) {
          return _this3.selecteRef = _ref;
        },
        showSearch: true,
        allowClear: true,
        combobox: true // backfill
        // disabled
        // multiple
        // filterOption
        ,
        disabled: disabled,
        onFocus: this.onFocus // onSearch={this.onSearch}
        ,
        placeholder: this.props.placeholder,
        notFoundContent: this.props.notFoundContent // notFoundContent="暂无数据"
        ,
        onChange: this.onChange,
        onSelect: this.onSelect,
        value: this.state.value
      }, this.state.options.map(function (item) {
        return React.createElement(Option, {
          value: item.code + ' ' + item.name,
          title: item.name,
          id: item.id // ode={item.code}
          ,
          key: item.id,
          disabled: item.disabled
        }, isCode ? item.code + ' ' + item.name : item.name);
      }));
    }
  }]);

  return ReferComponents;
}(React.Component);

var noop = function noop() {
  return null;
};

ReferComponents.propTypes = {
  url: PropTypes.string,
  method: PropTypes.string,
  contentType: PropTypes.string,
  dataType: PropTypes.string,
  sendData: PropTypes.object,
  fixedData: PropTypes.object,
  beforeSend: PropTypes.func,
  onChange: PropTypes.func,
  disabled: PropTypes.bool,
  value: PropTypes.object,
  isCode: PropTypes.bool,
  placeholder: PropTypes.string,
  notFoundContent: PropTypes.string,
  defaultCode: PropTypes.bool
};
ReferComponents.defaultProps = {
  url: '',
  method: 'POST',
  contentType: 'application/json; charset=utf-8',
  dataType: 'json',
  sendData: {
    refCode: '',
    refType: 'list',
    funcode: '',
    displayFields: ['id', 'code', 'name']
  },
  fixedData: {},
  beforeSend: noop,
  onChange: noop,
  disabled: false,
  value: {},
  isCode: false,
  placeholder: '请输入...',
  notFoundContent: '暂无数据',
  defaultCode: ''
};
polyfill(ReferComponents);
export default ReferComponents;
